@@ -58,6 +58,8 @@ struct hdrl_collapse_imagelist_to_image_s {
     cpl_error_code (*move_eout)(void *, void *, const cpl_size);
     /* unwrap extra out storage */
     hdrl_free * unwrap_eout;
+    /* delete extra out storage */
+    void (*delete_eout)(void *);
     /* parameters the reduction function requires */
     hdrl_parameter * parameters;
 };
@@ -81,6 +83,8 @@ struct hdrl_collapse_imagelist_to_vector_s {
     cpl_error_code (*move_eout)(void *, void *, const cpl_size);
     /* unwrap extra out storage */
     hdrl_free * unwrap_eout;
+    /* delete extra out storage */
+    void (*delete_eout)(void *);
     /* parameters the reduction function requires */
     hdrl_parameter * parameters;
 };
@@ -89,34 +93,31 @@ static cpl_error_code
 hdrl_collapse_mean(const cpl_imagelist * data,
                    const cpl_imagelist * errors,
                    cpl_image ** out, cpl_image ** err,
-                   cpl_image ** contrib, void * parameters,
-                   void * extra_out);
+                   cpl_image ** contrib, void *, void *);
 static cpl_error_code
 hdrl_collapse_median(const cpl_imagelist * data,
                      const cpl_imagelist * errors,
                      cpl_image ** out, cpl_image ** err,
-                     cpl_image ** contrib, void * parameters,
-                     void * extra_out);
+                     cpl_image ** contrib, void *, void *);
 static cpl_error_code
 hdrl_collapse_sigclip(const cpl_imagelist * data,
                       const cpl_imagelist * errors,
                       cpl_image ** out, cpl_image ** err,
-                      cpl_image ** contrib,void * parameters,
-                      void * extra_out);
+                      cpl_image ** contrib,
+					  void * parameters, void * extra_out);
 
 static cpl_error_code
 hdrl_collapse_minmax(const cpl_imagelist * data,
                       const cpl_imagelist * errors,
                       cpl_image ** out, cpl_image ** err,
-                      cpl_image ** contrib,void * parameters,
-                      void * extra_out);
+                      cpl_image ** contrib,
+					  void * parameters, void * extra_out);
 
 static cpl_error_code
 hdrl_collapse_weighted_mean(const cpl_imagelist * data_,
                             const cpl_imagelist * errors_,
                             cpl_image ** out, cpl_image ** err,
-                            cpl_image ** contrib, void * parameters,
-                            void * extra_out);
+                            cpl_image ** contrib, void *, void *);
 
 /*-----------------------------------------------------------------------------
                                    Static
@@ -158,7 +159,8 @@ static hdrl_parameter_typeobj hdrl_collapse_mean_parameter_type = {
     sizeof(hdrl_collapse_mean_parameter),   /* obj_size */
 };
 
-HDRL_PARAMETER_SINGLETON(HDRL_COLLAPSE_MEAN, hdrl_collapse_mean_parameter_type,
+HDRL_PARAMETER_SINGLETON(HDRL_COLLAPSE_MEAN,
+						 hdrl_collapse_mean_parameter_type,
                          hdrl_mean_alloc);
 
 /* Median COLLAPSE */
@@ -357,11 +359,11 @@ cpl_error_code hdrl_collapse_sigclip_parameter_verify(
                      "Not a Sigclip parameter");
 
     const hdrl_collapse_sigclip_parameter * param_loc =
-            (hdrl_collapse_sigclip_parameter *)param ;
+            (const hdrl_collapse_sigclip_parameter *)param ;
 
-    cpl_error_ensure(param_loc->niter >= 0, CPL_ERROR_ILLEGAL_INPUT,
+    cpl_error_ensure(param_loc->niter > 0, CPL_ERROR_ILLEGAL_INPUT,
             return CPL_ERROR_ILLEGAL_INPUT,
-            "sigma-clipping iter (%d) value must be >= 0", 
+            "sigma-clipping iter (%d) value must be > 0",
             param_loc->niter);
 
     return CPL_ERROR_NONE ;
@@ -382,7 +384,7 @@ double hdrl_collapse_sigclip_parameter_get_kappa_high(const hdrl_parameter * p)
     cpl_ensure(hdrl_collapse_parameter_is_sigclip(p), 
             CPL_ERROR_INCOMPATIBLE_INPUT, -1);
 
-    return ((hdrl_collapse_sigclip_parameter *)p)->kappa_high;
+    return ((const hdrl_collapse_sigclip_parameter *)p)->kappa_high;
 }
 
 /* ---------------------------------------------------------------------------*/
@@ -398,7 +400,7 @@ double hdrl_collapse_sigclip_parameter_get_kappa_low(const hdrl_parameter * p)
     cpl_ensure(hdrl_collapse_parameter_is_sigclip(p), 
             CPL_ERROR_INCOMPATIBLE_INPUT, -1);
 
-    return ((hdrl_collapse_sigclip_parameter *)p)->kappa_low;
+    return ((const hdrl_collapse_sigclip_parameter *)p)->kappa_low;
 }
 
 /* ---------------------------------------------------------------------------*/
@@ -414,7 +416,7 @@ int hdrl_collapse_sigclip_parameter_get_niter(const hdrl_parameter * p)
     cpl_ensure(hdrl_collapse_parameter_is_sigclip(p), 
             CPL_ERROR_INCOMPATIBLE_INPUT, -1);
 
-    return ((hdrl_collapse_sigclip_parameter *)p)->niter;
+    return ((const hdrl_collapse_sigclip_parameter *)p)->niter;
 }
 
 /* ---------------------------------------------------------------------------*/
@@ -478,7 +480,7 @@ cpl_error_code hdrl_collapse_minmax_parameter_verify(
                      "Not a minmax parameter");
 
     const hdrl_collapse_minmax_parameter * param_loc =
-            (hdrl_collapse_minmax_parameter *)param ;
+            (const hdrl_collapse_minmax_parameter *)param ;
 
     cpl_error_ensure(param_loc->nlow >= 0, CPL_ERROR_ILLEGAL_INPUT,
             return CPL_ERROR_ILLEGAL_INPUT,
@@ -508,7 +510,7 @@ double hdrl_collapse_minmax_parameter_get_nhigh(const hdrl_parameter * p)
     cpl_ensure(hdrl_collapse_parameter_is_minmax(p),
             CPL_ERROR_INCOMPATIBLE_INPUT, -1);
 
-    return ((hdrl_collapse_minmax_parameter *)p)->nhigh;
+    return ((const hdrl_collapse_minmax_parameter *)p)->nhigh;
 }
 
 /* ---------------------------------------------------------------------------*/
@@ -524,7 +526,7 @@ double hdrl_collapse_minmax_parameter_get_nlow(const hdrl_parameter * p)
     cpl_ensure(hdrl_collapse_parameter_is_minmax(p),
             CPL_ERROR_INCOMPATIBLE_INPUT, -1);
 
-    return ((hdrl_collapse_minmax_parameter *)p)->nlow;
+    return ((const hdrl_collapse_minmax_parameter *)p)->nlow;
 }
 
 
@@ -544,17 +546,22 @@ double hdrl_collapse_minmax_parameter_get_nlow(const hdrl_parameter * p)
  */
 /* ---------------------------------------------------------------------------*/
 cpl_parameterlist * hdrl_collapse_parameter_create_parlist(
-        const char      *   base_context,
-        const char      *   prefix,
-        const char      *   method_def,
-        hdrl_parameter  *   sigclip_def,
-        hdrl_parameter  *   minmax_def)
+        const char     *base_context,
+        const char     *prefix,
+        const char     *method_def,
+        hdrl_parameter *sigclip_def,
+        hdrl_parameter *minmax_def)
 {
     cpl_ensure(base_context && prefix, CPL_ERROR_NULL_INPUT, NULL);
-    char                *   name ;
-    cpl_parameterlist   *   parlist = cpl_parameterlist_new();
-    cpl_parameter       *   p ;
-    char                *   context = hdrl_join_string(".", 2, base_context, prefix);
+
+    cpl_ensure(    hdrl_collapse_parameter_is_sigclip(sigclip_def)
+				&& hdrl_collapse_parameter_is_minmax( minmax_def ),
+       		CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+
+    char              *name;
+    cpl_parameterlist *parlist = cpl_parameterlist_new();
+    cpl_parameter     *p;
+    char              *context = hdrl_join_string(".", 2, base_context, prefix);
 
     /* --prefix.method */
     name = hdrl_join_string(".", 2, context, "method");
@@ -582,8 +589,6 @@ cpl_parameterlist * hdrl_collapse_parameter_create_parlist(
     }
     cpl_parameterlist_delete(psigclip);
 
-
-
     /* --prefix.minmax.xxx */
     name = hdrl_join_string(".", 2, prefix, "minmax");
     cpl_parameterlist * pminmax = hdrl_minmax_parameter_create_parlist(
@@ -686,17 +691,22 @@ hdrl_parameter * hdrl_collapse_parameter_parse_parlist(
 static cpl_imagelist *
 wrap_synced_errlist(const cpl_imagelist * data, const cpl_imagelist * errors)
 {
-
     cpl_imagelist * nerrors = cpl_imagelist_new();
     for (size_t i = 0; i < (size_t)cpl_imagelist_get_size(errors); i++) {
         const cpl_image * img = cpl_imagelist_get_const(data, i);
         const cpl_image * err = cpl_imagelist_get_const(errors, i);
+
+        CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
+
         cpl_image * nerr = cpl_image_wrap(cpl_image_get_size_x(err),
                                           cpl_image_get_size_y(err),
                                           cpl_image_get_type(err),
                                           (void*)cpl_image_get_data_const(err));
         cpl_mask_delete(hcpl_image_set_bpm(nerr,
                                   (cpl_mask*)cpl_image_get_bpm_const(img)));
+
+        CPL_DIAG_PRAGMA_POP;
+
         cpl_imagelist_set(nerrors, nerr, i);
     }
     return nerrors;
@@ -713,8 +723,13 @@ static void
 unwrap_synced_errlist(cpl_imagelist * nerrors)
 {
     for (size_t i = 0; i < (size_t)cpl_imagelist_get_size(nerrors); i++) {
+
+        CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
+
         cpl_image * err = (cpl_image*)cpl_imagelist_get_const(nerrors, i);
 
+        CPL_DIAG_PRAGMA_POP;
+
         cpl_image_unset_bpm(err);
         cpl_image_unwrap(err);
     }
@@ -806,12 +821,29 @@ hdrl_collapse_mean(const cpl_imagelist * data,
 {
     /* (\Sum_i^n x_i) / n */
     /* \sqrt(\Sum_i^n x_i^2) / n */
+    cpl_errorstate prestate = cpl_errorstate_get();
     *out = cpl_imagelist_collapse_create(data);
-    *err = imagelist_sqsum(errors, contrib);
-    cpl_image_power(*err, 0.5);
-    cpl_image_divide(*err, *contrib);
-    cpl_image_fill_rejected(*out, NAN);
-    cpl_image_fill_rejected(*err, NAN);
+    /* ignore division by 0 on all pixels zero error */
+    if (*out == NULL) {
+        cpl_errorstate_set(prestate);
+        *out = cpl_image_duplicate(cpl_imagelist_get_const(data, 0));
+        cpl_image_accept_all(*out);
+        cpl_mask_not(cpl_image_get_bpm(*out));
+        *err = cpl_image_duplicate(cpl_imagelist_get_const(errors, 0));
+        cpl_image_accept_all(*err);
+        cpl_mask_not(cpl_image_get_bpm(*err));
+        *contrib = cpl_image_new(cpl_image_get_size_x(*err),
+                                 cpl_image_get_size_y(*err), CPL_TYPE_INT);
+        cpl_image_fill_rejected(*out, NAN);
+        cpl_image_fill_rejected(*err, NAN);
+    }
+    else {
+        *err = imagelist_sqsum(errors, contrib);
+        cpl_image_power(*err, 0.5);
+        cpl_image_divide(*err, *contrib);
+        cpl_image_fill_rejected(*out, NAN);
+        cpl_image_fill_rejected(*err, NAN);
+    }
 
     return cpl_error_get_code();
 }
@@ -853,17 +885,32 @@ hdrl_collapse_weighted_mean(const cpl_imagelist * data_,
 {
     /* (\Sum_i^n w_i * x_i) / (\Sum_i^n w_i) */
     /* 1 / \sqrt(\Sum_i^n w_i^2) */
+    cpl_errorstate prestate = cpl_errorstate_get();
     cpl_imagelist * data = cpl_imagelist_duplicate(data_);
     cpl_imagelist * errors = cpl_imagelist_new();
     cpl_image * tmperr;
     cpl_imagelist_cast(errors, errors_,
                        cpl_image_get_type(cpl_imagelist_get(data, 0)));
-    *contrib = cpl_image_new_from_accepted(data);
     cpl_imagelist_power(errors, -2);
     cpl_imagelist_multiply(data, errors);
+    *contrib = cpl_image_new_from_accepted(data);
     *out = cpl_imagelist_collapse_create(data);
-    tmperr = cpl_imagelist_collapse_create(errors);
+    if (*out == NULL) {
+        cpl_errorstate_set(prestate);
+        *out = cpl_image_duplicate(cpl_imagelist_get_const(data, 0));
+        cpl_image_accept_all(*out);
+        cpl_mask_not(cpl_image_get_bpm(*out));
+        *err = cpl_image_duplicate(cpl_imagelist_get_const(errors, 0));
+        cpl_image_accept_all(*err);
+        cpl_mask_not(cpl_image_get_bpm(*err));
+        cpl_image_fill_rejected(*out, NAN);
+        cpl_image_fill_rejected(*err, NAN);
+        cpl_imagelist_delete(errors);
+        cpl_imagelist_delete(data);
+        return cpl_error_get_code();
+    }
     cpl_imagelist_delete(data);
+    tmperr = cpl_imagelist_collapse_create(errors);
     cpl_imagelist_delete(errors);
     cpl_image_multiply(*out, *contrib);
     cpl_image_multiply(tmperr, *contrib);
@@ -912,11 +959,22 @@ hdrl_collapse_median(const cpl_imagelist * data,
                                void * HDRL_UNUSED(parameters),
                                void * HDRL_UNUSED(extra_out))
 {
+    cpl_errorstate prestate = cpl_errorstate_get();
     /* same as mean with scaling by \sqrt(\pi / 2) */
     *out = cpl_imagelist_collapse_median_create(data);
     *err = imagelist_sqsum(errors, contrib);
     cpl_image_power(*err, 0.5);
     cpl_image_divide(*err, *contrib);
+    if (cpl_error_get_code() == CPL_ERROR_DIVISION_BY_ZERO) {
+        cpl_errorstate_set(prestate);
+        cpl_image_accept_all(*out);
+        cpl_mask_not(cpl_image_get_bpm(*out));
+        cpl_image_accept_all(*err);
+        cpl_mask_not(cpl_image_get_bpm(*err));
+        cpl_image_fill_rejected(*out, NAN);
+        cpl_image_fill_rejected(*err, NAN);
+        return cpl_error_get_code();
+    }
     /* scale error so it estimates stdev of normal distribution */
     cpl_image_multiply_scalar(*err, sqrt(CPL_MATH_PI_2));
     /* revert scaling for contrib <= 2 as median == mean in this case */
@@ -953,8 +1011,8 @@ static cpl_error_code
 hdrl_collapse_sigclip(const cpl_imagelist * data,
                       const cpl_imagelist * errors,
                       cpl_image ** out, cpl_image ** err,
-                      cpl_image ** contrib, void * parameters,
-                      void * extra_out)
+                      cpl_image ** contrib,
+					  void * parameters, void * extra_out)
 {
     /* same as mean but working on the not-clipped values only */
     hdrl_collapse_sigclip_parameter * par = parameters;
@@ -967,13 +1025,15 @@ hdrl_collapse_sigclip(const cpl_imagelist * data,
     *out = cpl_image_new(nx, ny, HDRL_TYPE_DATA);
     *err = cpl_image_new(nx, ny, HDRL_TYPE_ERROR);
     *contrib = cpl_image_new(nx, ny, CPL_TYPE_INT);
+    hdrl_vector_cache * cache =
+        hdrl_vector_cache_new(cpl_imagelist_get_size(data), nx * 2);
 
     /* sigmaclip along imagelist axis */
     for (size_t y = 1; y < ny + 1; y++) {
         cpl_vector * vdv[nx];
         cpl_vector * vev[nx];
-        hdrl_imagelist_to_vector_row(data, y, vdv);
-        hdrl_imagelist_to_vector_row(errors, y, vev);
+        hdrl_imagelist_to_vector_row(data, y, vdv, cache);
+        hdrl_imagelist_to_vector_row(errors, y, vev, cache);
         for (size_t x = 1; x < nx + 1; x++) {
             cpl_vector * vd = vdv[x - 1];
             cpl_vector * ve = vev[x - 1];
@@ -1004,10 +1064,11 @@ hdrl_collapse_sigclip(const cpl_imagelist * data,
                     cpl_image_set(eout->reject_high, x, y, 0.);
                 }
             }
-            cpl_vector_delete(vd);
-            cpl_vector_delete(ve);
+            hdrl_cplvector_delete_to_cache(cache, vd);
+            hdrl_cplvector_delete_to_cache(cache, ve);
         }
     }
+    hdrl_vector_cache_delete(cache);
 
     return cpl_error_get_code();
 }
@@ -1038,8 +1099,8 @@ static cpl_error_code
 hdrl_collapse_minmax(const cpl_imagelist * data,
                      const cpl_imagelist * errors,
                      cpl_image ** out, cpl_image ** err,
-                     cpl_image ** contrib, void * parameters,
-                     void * extra_out)
+                     cpl_image ** contrib,
+					 void * parameters, void * extra_out)
 {
     /* same as mean but working on the not-clipped values only */
     hdrl_collapse_minmax_parameter * par = parameters;
@@ -1052,13 +1113,15 @@ hdrl_collapse_minmax(const cpl_imagelist * data,
     *out = cpl_image_new(nx, ny, HDRL_TYPE_DATA);
     *err = cpl_image_new(nx, ny, HDRL_TYPE_ERROR);
     *contrib = cpl_image_new(nx, ny, CPL_TYPE_INT);
+    hdrl_vector_cache * cache =
+        hdrl_vector_cache_new(cpl_imagelist_get_size(data), nx * 2);
 
     /* minmaxclip along imagelist axis */
     for (size_t y = 1; y < ny + 1; y++) {
         cpl_vector * vdv[nx];
         cpl_vector * vev[nx];
-        hdrl_imagelist_to_vector_row(data, y, vdv);
-        hdrl_imagelist_to_vector_row(errors, y, vev);
+        hdrl_imagelist_to_vector_row(data, y, vdv, cache);
+        hdrl_imagelist_to_vector_row(errors, y, vev, cache);
         for (size_t x = 1; x < nx + 1; x++) {
             cpl_vector * vd = vdv[x - 1];
             cpl_vector * ve = vev[x - 1];
@@ -1066,7 +1129,7 @@ hdrl_collapse_minmax(const cpl_imagelist * data,
                 double m, e, rej_low, rej_high;
                 cpl_size naccepted;
                 hdrl_minmax_clip(vd, ve,
-                                 par->nlow, par->nhigh, CPL_FALSE,
+                                 par->nlow, par->nhigh, CPL_TRUE,
                                  &m, &e, &naccepted,
                                  &rej_low, &rej_high);
                 cpl_image_set(*out, x, y, m);
@@ -1088,10 +1151,11 @@ hdrl_collapse_minmax(const cpl_imagelist * data,
                     cpl_image_set(eout->reject_high, x, y, 0.);
                 }
             }
-            cpl_vector_delete(vd);
-            cpl_vector_delete(ve);
+            hdrl_cplvector_delete_to_cache(cache, vd);
+            hdrl_cplvector_delete_to_cache(cache, ve);
         }
     }
+    hdrl_vector_cache_delete(cache);
 
     return cpl_error_get_code();
 }
@@ -1135,6 +1199,7 @@ hdrl_collapse_imagelist_to_image_t *
     s->create_eout = &hdrl_nop_create_eout_img;
     s->move_eout = &hdrl_nop_move_eout;
     s->unwrap_eout = &hdrl_nop_unwrap_eout;
+    s->delete_eout = &hdrl_nop_unwrap_eout;
     return s;
 }
 
@@ -1152,6 +1217,7 @@ hdrl_collapse_imagelist_to_image_t *
     s->create_eout = &hdrl_nop_create_eout_img;
     s->move_eout = &hdrl_nop_move_eout;
     s->unwrap_eout = &hdrl_nop_unwrap_eout;
+    s->delete_eout = &hdrl_nop_unwrap_eout;
     return s;
 }
 
@@ -1169,6 +1235,7 @@ hdrl_collapse_imagelist_to_image_t *
     s->create_eout = &hdrl_nop_create_eout_img;
     s->move_eout = &hdrl_nop_move_eout;
     s->unwrap_eout = &hdrl_nop_unwrap_eout;
+    s->delete_eout = &hdrl_nop_unwrap_eout;
     return s;
 }
 
@@ -1189,6 +1256,18 @@ hdrl_sigclip_create_eout_img(const cpl_image * img)
     return eout;
 }
 
+static void
+hdrl_sigclip_delete_eout_img(void * eout_)
+{
+    if (eout_ == NULL) {
+        return;
+    }
+    hdrl_sigclip_image_output * eout = (hdrl_sigclip_image_output*)eout_;
+    cpl_image_delete(eout->reject_low);
+    cpl_image_delete(eout->reject_high);
+    cpl_free(eout);
+}
+
 static cpl_error_code
 hdrl_sigclip_move_eout_img(void * dst_, void * src_, const cpl_size y)
 {
@@ -1235,6 +1314,7 @@ hdrl_collapse_imagelist_to_image_sigclip(double kappa_low,
     s->create_eout = &hdrl_sigclip_create_eout_img;
     s->move_eout = &hdrl_sigclip_move_eout_img;
     s->unwrap_eout = &cpl_free;
+    s->delete_eout = &hdrl_sigclip_delete_eout_img;
     s->parameters = sp;
     return s;
 }
@@ -1263,6 +1343,7 @@ hdrl_collapse_imagelist_to_image_minmax(double nlow,
     s->create_eout = &hdrl_sigclip_create_eout_img;
     s->move_eout = &hdrl_sigclip_move_eout_img;
     s->unwrap_eout = &cpl_free;
+    s->delete_eout = &hdrl_sigclip_delete_eout_img;
     s->parameters = sp;
     return s;
 }
@@ -1360,6 +1441,26 @@ hdrl_collapse_imagelist_to_image_unwrap_eout(
     }
 }
 
+/* ---------------------------------------------------------------------------*/
+/**
+ * @brief call extra output delete function
+ *
+ * @param f     reduction function object
+ *
+ * @note does delete the members
+ *
+ */
+/* ---------------------------------------------------------------------------*/
+void
+hdrl_collapse_imagelist_to_image_delete_eout(
+                         hdrl_collapse_imagelist_to_image_t * f,
+                         void * eout)
+{
+    if (f != NULL) {
+        f->delete_eout(eout);
+    }
+}
+
 /* ---------------------------------------------------------------------------*/
 /**
  * @brief call function to move extra output do destination with offset
@@ -1413,8 +1514,7 @@ void hdrl_collapse_imagelist_to_image_delete(hdrl_collapse_imagelist_to_image_t
  *         function
  */
 /* ---------------------------------------------------------------------------*/
-void *
-hdrl_collapse_imagelist_to_vector_create_eout(
+void * hdrl_collapse_imagelist_to_vector_create_eout(
                          hdrl_collapse_imagelist_to_vector_t * f,
                          const cpl_size size)
 {
@@ -1444,6 +1544,25 @@ hdrl_collapse_imagelist_to_vector_unwrap_eout(
     }
 }
 
+/* ---------------------------------------------------------------------------*/
+/**
+ * @brief call extra output delete function
+ *
+ * @param f     reduction function object
+ *
+ * @note does delete the members
+ *
+ */
+/* ---------------------------------------------------------------------------*/
+void hdrl_collapse_imagelist_to_vector_delete_eout(
+                         hdrl_collapse_imagelist_to_vector_t * f,
+                         void * eout)
+{
+    if (f != NULL) {
+        f->delete_eout(eout);
+    }
+}
+
 /* ---------------------------------------------------------------------------*/
 /**
  * @brief call function to move extra output do destination with offset
@@ -1458,8 +1577,7 @@ hdrl_collapse_imagelist_to_vector_unwrap_eout(
  * @note deletes the source after the content is copied
  */
 /* ---------------------------------------------------------------------------*/
-cpl_error_code
-hdrl_collapse_imagelist_to_vector_move_eout(
+cpl_error_code hdrl_collapse_imagelist_to_vector_move_eout(
                        hdrl_collapse_imagelist_to_vector_t * f,
                        void * dst,
                        void * src,
@@ -1540,6 +1658,7 @@ hdrl_collapse_imagelist_to_vector_t *
     s->create_eout = &hdrl_nop_create_eout_vec;
     s->move_eout = &hdrl_nop_move_eout;
     s->unwrap_eout = &hdrl_nop_unwrap_eout;
+    s->delete_eout = &hdrl_nop_unwrap_eout;
     s->func = &reduce_imagelist_to_vector_mean;
     return s;
 }
@@ -1630,6 +1749,7 @@ hdrl_collapse_imagelist_to_vector_t *
     s->create_eout = &hdrl_nop_create_eout_vec;
     s->move_eout = &hdrl_nop_move_eout;
     s->unwrap_eout = &hdrl_nop_unwrap_eout;
+    s->delete_eout = &hdrl_nop_unwrap_eout;
     s->func = &reduce_imagelist_to_vector_weighted_mean;
     return s;
 }
@@ -1709,6 +1829,7 @@ hdrl_collapse_imagelist_to_vector_t *
     s->create_eout = &hdrl_nop_create_eout_vec;
     s->move_eout = &hdrl_nop_move_eout;
     s->unwrap_eout = &hdrl_nop_unwrap_eout;
+    s->delete_eout = &hdrl_nop_unwrap_eout;
     s->func = &reduce_imagelist_to_vector_median;
     return s;
 }
@@ -1722,6 +1843,18 @@ hdrl_sigclip_create_eout_vec(cpl_size size)
     return eout;
 }
 
+static void
+hdrl_sigclip_delete_eout_vec(void * eout_)
+{
+    if (eout_ == NULL) {
+        return;
+    }
+    hdrl_sigclip_vector_output * eout = (hdrl_sigclip_vector_output*)eout_;
+    cpl_vector_delete(eout->reject_low);
+    cpl_vector_delete(eout->reject_high);
+    cpl_free(eout);
+}
+
 static cpl_error_code
 hdrl_sigclip_move_eout_vec(void * dst_, void * src_, const cpl_size y)
 {
@@ -1834,6 +1967,7 @@ hdrl_collapse_imagelist_to_vector_sigclip(double kappa_low, double kappa_high,
     s->create_eout = &hdrl_sigclip_create_eout_vec;
     s->move_eout = &hdrl_sigclip_move_eout_vec;
     s->unwrap_eout = &cpl_free;
+    s->delete_eout = &hdrl_sigclip_delete_eout_vec;
     s->parameters = sp;
     return s;
 }
@@ -1919,6 +2053,7 @@ hdrl_collapse_imagelist_to_vector_minmax(double nlow, double nhigh)
     s->create_eout = &hdrl_sigclip_create_eout_vec;
     s->move_eout = &hdrl_sigclip_move_eout_vec;
     s->unwrap_eout = &cpl_free;
+    s->delete_eout = &hdrl_sigclip_delete_eout_vec;
     s->parameters = sp;
     return s;
 }
