@@ -522,6 +522,14 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
       * because we need to have the calib frameset with input frames already with correct binning
       * that is done by xsh_set_recipe_file_prefix (which needs frames in PRE format)
       */
+  /* PIPE-9018: But we also need to have pre-overscan-corr properly set */
+  /* This assignment of pre_overscan_corr does not need to be replicated in
+   * xsh_scired_slit_nod because xsh_scired_nod_get_calibs sets the parameter correctly
+   * before xsh_prepare is called - as described above, this needs to be triggered
+   * earlier in this recipe */
+   check( pre_overscan_corr = xsh_parameters_get_int( parameters, RECIPE_ID,
+                                                             "pre-overscan-corr"));
+
    check( xsh_prepare( raws_ord_set, bpmap, master_bias, XSH_OBJECT_SLIT_NOD,
             instrument,pre_overscan_corr,CPL_TRUE));
 
