@@ -789,7 +789,7 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
       check( a_b = cpl_frameset_get_frame( rmbkg_frameset, i ) ) ;
       sprintf( file_tag, "NO_CRH_IFU_OFFSET_%s%d", arm_str,i);
       xsh_msg( "Remove crh (single frame)" );
-      check( rm_crh = xsh_remove_crh_single( a_b,instrument,
+      check( rm_crh = xsh_remove_crh_single( a_b,instrument,NULL,
 					     crh_single_par,
 					     file_tag ));
       check( cpl_frameset_insert( nocrh_frameset, rm_crh));
