@@ -120,6 +120,7 @@ Tag = OBJECT_SLIT_STARE_UVB)\n\
   - [OPTIONAL,physmod mode] A table listing sky line positions (Tag = SKY_LINE_LIST_arm)\n\
     this is used to be able to control quality of sky subtraction, for example\n\
     projecting guess positions on the product SCI_SLIT_STARE_SUB_SKY_arm\n\
+    and is required if sky-method=BSPLINE\n\
   - [OPTIONAL] The instrument response table (Tag = RESPONSE_MERGE1D_SLIT_arm)\n\
   - [OPTIONAL] An atmospheric extinction table (Tag = ATMOS_EXT_arm)\n\
   - [OPTIONAL] A telluric mask (Tag = TELL_MASK_arm)\n\
@@ -1069,8 +1070,8 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
 				RECIPE_ID, instrument));
     check( xsh_add_product_image( sky_frame_ima, frameset, parameters,
 				  RECIPE_ID, instrument,NULL));
-    check( xsh_add_product_orders_spectrum( sky_frame_eso, frameset,
-                                  parameters, RECIPE_ID, instrument,NULL));
+    xsh_add_product_table(sky_frame_eso, frameset, parameters, RECIPE_ID,
+    		instrument, NULL);
   }
   if(frame_backg != NULL) {
      check( xsh_add_product_image( frame_backg, frameset, parameters, 
