@@ -83,18 +83,27 @@
 /* nbreak = ncoeffs +2 -k = ncoeffs -2 since k = 4 */
 #define NBREAK (NCOEFFS -2)
 
-/**
-  @brief
-    Unit test of xsh_bspline
-  @return
-    0 if success
 
-*/
-int main()
-{
-  /* Declarations */
-  int ret =0;
+int
+test_gsl_table(const char* fname) {
 
+   cpl_table* t=NULL;
+   double* w=NULL;
+   double* f=NULL;
+   double* e=NULL;
+
+   t=cpl_table_load(fname,1,0);
+
+   w=cpl_table_get_data_double(t,"WAVE");
+   f=cpl_table_get_data_double(t,"FLUX");
+   e=cpl_table_get_data_double(t,"ERR");
+
+
+
+
+}
+
+int test_gsl_example() {
 
   const size_t n = N;
   const size_t ncoeffs = NCOEFFS;
@@ -111,8 +120,6 @@ int main()
   double chisq, dof; 
   //double tss, Rsq;
 
-  /* Initialize libraries */
-  TESTS_INIT(MODULE_ID);
 
   gsl_rng_env_setup();
   r = gsl_rng_alloc(gsl_rng_default);
@@ -186,7 +193,6 @@ int main()
   fprintf(stderr, "chisq/dof = %e, Rsq = %f\n", 
                    chisq / dof, Rsq);
   */
-
   /* output the smoothed curve */
   {
     double xi, yi, yerr;
@@ -200,8 +206,6 @@ int main()
       }
   }
 
-  //cleanup:
-
   gsl_rng_free(r);
   gsl_bspline_free(bw);
   gsl_vector_free(B);
@@ -213,12 +217,42 @@ int main()
   gsl_matrix_free(cov);
   gsl_multifit_linear_free(mw);
 
+}
+
+/**
+  @brief
+    Unit test of xsh_bspline
+  @return
+    0 if success
+
+*/
+int main(int argc, char * const argv[])
+{
+    /* Declarations */
+    int ret =0;
+    const char* file_on = NULL ;
+    /* Initialize libraries */
+    cpl_test_init("amodigli@eso.org", CPL_MSG_WARNING);
+
+    if (argc == 1)
+    {
+            test_gsl_example();
+    }
+    else if(argc == 2)
+    {
+		file_on = argv[1];
+
+    } else {
+		fprintf(stderr, "usage: %s table.fits\n", argv[0]);
+		return 0;
+    }
+
 
     if (cpl_error_get_code() != CPL_ERROR_NONE) {
       xsh_error_dump(CPL_MSG_ERROR);
       ret= 1;
     }
-    TEST_END();
+    cpl_test_end(0);
     return ret ;
 }
 
