@@ -178,6 +178,8 @@ int main(void)
   (void) remove(PRODUCT_FILE_NAME);
   (void) remove(OUTPUT_FILE_NAME);
   errno = 0;
+
+  printf("I'm inside the main of xsh_dfs_sdp");
   
   /* Create an empty parameter list. */
   cpl_parameterlist* params = cpl_parameterlist_new();
@@ -283,6 +285,9 @@ static int create_dummy_raw_frame(cpl_frameset* frames)
   cpl_test_assert(cpl_propertylist_append_string(props, XSH_SDP_KEYWORD_OBJECT,
                                                  OBJECT_VALUE)
                   == CPL_ERROR_NONE);
+    cpl_test_assert(cpl_propertylist_append_string(props, XSH_DPR_TYPE,
+                                                   OBJECT_VALUE)
+                    == CPL_ERROR_NONE);
   cpl_test_assert(cpl_propertylist_append_string(props, XSH_OBS_TARG_NAME,
                                                  TARGET_NAME)
                   == CPL_ERROR_NONE);
