@@ -585,13 +585,13 @@ xsh_compute_scale_factors_pix_pix(cpl_imagelist* scaled, cpl_image* scale,
 
 	int hbox_sz=6;// was 6
 	int lmin=0, lmax=0;
-	int sx=0;
-	int sy=0;
+	//int sx=0;
+	//int sy=0;
 	for (int nf = 0; nf < nb_frames; nf++) {
 		ima_tmp=cpl_imagelist_get(scaled,nf);
 		mask=cpl_image_get_bpm_const(ima_tmp);
-		sx=cpl_mask_get_size_x(mask);
-		sy=cpl_mask_get_size_y(mask);
+		//sx=cpl_mask_get_size_x(mask);
+		//sy=cpl_mask_get_size_y(mask);
 		//xsh_msg("nlambda=%d",nlambda);
 		scale=cpl_image_new(nlambda,nslit,CPL_TYPE_DOUBLE);
 		cpl_image_add_scalar(scale,1.);
@@ -806,7 +806,7 @@ xsh_find_image_scale_factors(xsh_rec_list *dest, xsh_rec_list **from,
 		int method, const int decode_bp, int scale_method)
 {
 
-	cpl_image* scale;
+	cpl_image* scale=NULL;
 
 	int nslit, from_slit, nlambda;
 	nslit = xsh_rec_list_get_nslit( dest, no);
@@ -1131,6 +1131,8 @@ xsh_fill_gauss(float** pgauss, const int sx, const int sy, const double A,
     return;
 }
  */
+
+#if 0
 static void
 xsh_rec_list_fill_gauss(xsh_rec_list *dest, xsh_rec_list **from,
 		int *slit_index, int nb_frames, int no,
@@ -1232,7 +1234,7 @@ xsh_rec_list_fill_gauss(xsh_rec_list *dest, xsh_rec_list **from,
 	return;
 
 }
-
+#endif
 /* TODO: NOT USED
 static double
 xsh_compute_scale_nod(xsh_rec_list **from,int *slit_index,
@@ -1461,12 +1463,12 @@ xsh_rec_list_add(xsh_rec_list *dest, xsh_rec_list **from,
 		for (nl = 0; nl < nlambda; nl++) {
 
 			int dest_idx;
-			int good = 0, bad = 0;
+			//int good = 0, bad = 0;
 			int isum =0;
 			//double dest_err = 0, dest_data = 0. ;
 			//double bad_err = 0, bad_data = 0;
 			unsigned int qflag = QFLAG_GOOD_PIXEL;
-			unsigned int badflag = QFLAG_GOOD_PIXEL;
+			//unsigned int badflag = QFLAG_GOOD_PIXEL;
 			int from_idx;
 			dest_idx = nl + ns * nlambda;
 
@@ -1604,7 +1606,7 @@ xsh_correct_scale_w(xsh_rec_list *dest, xsh_rec_list **from,
 
 	double sum_good_pix=0.;
 	double sum_bad_pix=0.;
-	double norm_good_pix=0.;
+	//double norm_good_pix=0.;
 	XSH_ASSURE_NOT_NULL( dest);
 	XSH_ASSURE_NOT_NULL( from);
 	XSH_ASSURE_NOT_NULL( slit_index);
@@ -1708,7 +1710,7 @@ xsh_correct_scale_w(xsh_rec_list *dest, xsh_rec_list **from,
 			sum_bad_pix=0.;
 			num_good_pix=0;
 			num_bad_pix=0;
-			norm_good_pix=0.;
+			//norm_good_pix=0.;
 			//int sign_from=0;
 			//int sign_scal=0;
 			// to sum only over good pixels we flag the bad ones
@@ -1726,7 +1728,7 @@ xsh_correct_scale_w(xsh_rec_list *dest, xsh_rec_list **from,
 					from_idx = i + (ns - slit_index[nf]) * nlambda;
 
 					sprintf(cname,"f%d",nf);
-					int* pq=cpl_table_get_data_int(bp,cname);
+					const int* pq=cpl_table_get_data_int_const(bp,cname);
 
 					float * from_data1 = xsh_rec_list_get_data1( from[nf], no);
 					//float * from_errs1 = xsh_rec_list_get_errs1( from[nf], no);
@@ -1756,7 +1758,7 @@ xsh_correct_scale_w(xsh_rec_list *dest, xsh_rec_list **from,
 			scale = sum_all_pix/sum_good_pix*num_good_pix/nb_frames;
 
 			if(isinf(scale) || isnan(scale)) {
-				xsh_msg("found infinite sum_good: %g sum_bad: %g num_good: %g",
+				xsh_msg("found infinite sum_good: %g sum_bad: %g num_good: %d",
 						sum_good_pix, sum_bad_pix, num_good_pix);
 				xsh_msg("x_min=%d x_max=%d",x_min,x_max);
 
