@@ -608,11 +608,13 @@ xsh_resid_tab* xsh_resid_tab_load( cpl_frame* resid_tab_frame)
   cleanup:
     if (cpl_error_get_code () != CPL_ERROR_NONE) {
       xsh_error_msg("can't load frame %s",
-        cpl_frame_get_filename(resid_tab_frame));
+      cpl_frame_get_filename(resid_tab_frame));
       xsh_resid_tab_free(&result);
+      return NULL;
+    } else {
+      XSH_TABLE_FREE( table);
+      return result;
     }
-    XSH_TABLE_FREE( table);
-    return result;
 }
 
 /*---------------------------------------------------------------------------*/
