@@ -782,7 +782,7 @@ xsh_wavemap_list_sky_image_save( xsh_wavemap_list * smap,
 
     int order;
     int sx, sy ;
-    char fname[80];
+    //char fname[80];
     char * final_name = NULL;
 
     XSH_ASSURE_NOT_NULL( smap ) ;
@@ -796,13 +796,13 @@ xsh_wavemap_list_sky_image_save( xsh_wavemap_list * smap,
     sky_model = xsh_pre_new(sx,sy);
     fit_model = xsh_pre_new(sx,sy);
 
-    pdata_sky = cpl_image_get_data_float(xsh_pre_get_data_const(sky_model));
-    perrs_sky = cpl_image_get_data_float(xsh_pre_get_errs_const(sky_model));
-    pqual_sky = cpl_image_get_data_int(xsh_pre_get_qual_const(sky_model));
+    pdata_sky = cpl_image_get_data_float(xsh_pre_get_data(sky_model));
+    perrs_sky = cpl_image_get_data_float(xsh_pre_get_errs(sky_model));
+    pqual_sky = cpl_image_get_data_int(xsh_pre_get_qual(sky_model));
 
-    pdata_fit = cpl_image_get_data_float(xsh_pre_get_data_const(fit_model));
-    perrs_fit = cpl_image_get_data_float(xsh_pre_get_errs_const(fit_model));
-    pqual_fit = cpl_image_get_data_int(xsh_pre_get_qual_const(fit_model));
+    pdata_fit = cpl_image_get_data_float(xsh_pre_get_data(fit_model));
+    perrs_fit = cpl_image_get_data_float(xsh_pre_get_errs(fit_model));
+    pqual_fit = cpl_image_get_data_int(xsh_pre_get_qual(fit_model));
 
 
     /* associate to object and sky the corresponding wave and slit maps */
@@ -887,7 +887,7 @@ xsh_wavemap_list_object_image_save( xsh_wavemap_list * omap,
 
     int order;
     int sx, sy ;
-    char fname[80];
+    //char fname[80];
 
     XSH_ASSURE_NOT_NULL( omap ) ;
     XSH_ASSURE_NOT_NULL( instr ) ;
@@ -898,9 +898,9 @@ xsh_wavemap_list_object_image_save( xsh_wavemap_list * omap,
     /* create a model of the object and the sky as a PRE format frame */
     obj_model = xsh_pre_new(sx,sy);
 
-    pdata_obj = cpl_image_get_data_float(xsh_pre_get_data_const(obj_model));
-    perrs_obj = cpl_image_get_data_float(xsh_pre_get_errs_const(obj_model));
-    pqual_obj = cpl_image_get_data_int(xsh_pre_get_qual_const(obj_model));
+    pdata_obj = cpl_image_get_data_float(xsh_pre_get_data(obj_model));
+    perrs_obj = cpl_image_get_data_float(xsh_pre_get_errs(obj_model));
+    pqual_obj = cpl_image_get_data_int(xsh_pre_get_qual(obj_model));
 
     /* associate to object and sky the corresponding wave and slit maps */
     obj_wmap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
@@ -1007,13 +1007,13 @@ xsh_wavemap_list_save4debug( xsh_wavemap_list * wmap,
     obj_model = xsh_pre_new(sx,sy);
     sky_model = xsh_pre_new(sx,sy);
 
-    pdata_obj = cpl_image_get_data_float(xsh_pre_get_data_const(obj_model));
-    perrs_obj = cpl_image_get_data_float(xsh_pre_get_errs_const(obj_model));
-    pqual_obj = cpl_image_get_data_int(xsh_pre_get_qual_const(obj_model));
+    pdata_obj = cpl_image_get_data_float(xsh_pre_get_data(obj_model));
+    perrs_obj = cpl_image_get_data_float(xsh_pre_get_errs(obj_model));
+    pqual_obj = cpl_image_get_data_int(xsh_pre_get_qual(obj_model));
 
-    pdata_sky = cpl_image_get_data_float(xsh_pre_get_data_const(sky_model));
-    perrs_sky = cpl_image_get_data_float(xsh_pre_get_errs_const(sky_model));
-    pqual_sky = cpl_image_get_data_int(xsh_pre_get_qual_const(sky_model));
+    pdata_sky = cpl_image_get_data_float(xsh_pre_get_data(sky_model));
+    perrs_sky = cpl_image_get_data_float(xsh_pre_get_errs(sky_model));
+    pqual_sky = cpl_image_get_data_int(xsh_pre_get_qual(sky_model));
 
     /* associate to object and sky the corresponding wave and slit maps */
     obj_wmap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
