@@ -641,7 +641,16 @@
 #define XSH_MASTER_BP_MAP_VIS "MASTER_BP_MAP_VIS"
 #define XSH_MASTER_BP_MAP_NIR "MASTER_BP_MAP_NIR"
 
+#define XSH_BIAS_PD "BIAS_PD"
+#define XSH_BIAS_PD_UVB "BIAS_PD_UVB"
+#define XSH_BIAS_PD_VIS "BIAS_PD_VIS"
+#define XSH_BIAS_PD_NIR "BIAS_PD_NIR"
 
+#define XSH_BIAS_PD_MASK "BIAS_PD_MASK"
+#define XSH_BIAS_PD_MASK_UVB "BIAS_PD_MASK_UVB"
+#define XSH_BIAS_PD_MASK_VIS "BIAS_PD_MASK_VIS"
+#define XSH_BIAS_PD_MASK_NIR "BIAS_PD_MASK_NIR"
+#define XSH_BIAS_PD_MASK_AGC "BIAS_PD_MASK_AGC"
 
 #define XSH_MASTER_BP_MAP_NLIN "MASTER_BP_MAP_NLIN"
 #define XSH_MASTER_BP_MAP_NLIN_UVB "MASTER_BP_MAP_NLIN_UVB"
@@ -1372,6 +1381,8 @@
 			   XSH_CMP_TAG_ARM( tag, XSH_MASTER_BP_MAP_DARK) || \
 			   XSH_CMP_TAG_ARM( tag, XSH_MASTER_BP_MAP_FLAT) || \
 			   XSH_CMP_TAG_ARM( tag, XSH_BP_MAP) ||	\
+			   XSH_CMP_TAG_ARM( tag, XSH_BIAS_PD) ||	\
+			   XSH_CMP_TAG_ARM( tag, XSH_BIAS_PD_MASK) ||	\
 			   XSH_CMP_TAG_ARM( tag, XSH_BP_MAP_CP) ||	\
 			   XSH_CMP_TAG_ARM( tag, XSH_BP_MAP_HP) ||	\
 			   XSH_CMP_TAG_ARM( tag, XSH_BP_MAP_SP) ||	\
