@@ -531,6 +531,7 @@ cpl_frame* xsh_check_subtract_sky_single( int do_subsky,
         XSH_ASSURE_NOT_NULL( prefix);
 
         xsh_msg("---Sky subtraction (single frame)");
+        xsh_free_frame(&result);
         check( result = xsh_subtract_sky_single( src_frame, ordertabedges_frame,
                         slitmap_frame, wavemap_frame, loctab_frame,ref_sky_list,
                         sky_orders_chunks,
@@ -539,6 +540,7 @@ cpl_frame* xsh_check_subtract_sky_single( int do_subsky,
         sprintf( result_tag,"%s_SKY_%s", prefix,
                  xsh_instrument_arm_tostring(instrument));
         sprintf( result_name,"%s.fits", result_tag);
+        xsh_free_frame(sky_img);
         check( *sky_img = xsh_save_sky_model( src_frame, result, result_tag,
                         instrument));
         if(strstr(result_name,"TMPSKY")!=NULL) {
@@ -547,6 +549,7 @@ cpl_frame* xsh_check_subtract_sky_single( int do_subsky,
     }
     else{
         xsh_msg("[No sky subtraction]");
+        xsh_free_frame(&result);
         check( result = cpl_frame_duplicate( src_frame));
     }
 
