@@ -320,7 +320,7 @@ cpl_imagelist * xsh_fit_imagelist_polynomial(const cpl_vector    * x_pos,
             assert( 0 );
         }
 
-        cpl_vector_delete(xpow);
+        cpl_vector_unwrap(xpow);
 
     }
 
