@@ -550,7 +550,8 @@ typedef struct {
 #define DECODE_BP_FLAG_MAX  2147483647
 #define DECODE_BP_FLAG_ALL  2146435071
 #define DECODE_BP_FLAG_DEF  2144337919
-#define DECODE_BP_FLAG_NOD  1875902463
+//#define DECODE_BP_FLAG_NOD  1875902463  // Pre Jan 2021
+#define DECODE_BP_FLAG_NOD  1741684735  // PIPE-7965 update - MCW 21-01-19
 
 /*----------------------------------------------------------------------------
    				    Prototypes
