@@ -333,7 +333,7 @@
 #define XSH_SDP_KEYWORD_PROV(n)             "PROV"#n
 #define XSH_SDP_KEYWORD_NCOMBINE            "NCOMBINE"
 #define XSH_SDP_ADU_UNIT                    "adu"
-#define XSH_SDP_FLUX_UNIT                   "erg cm**(-2) s**(-1) angstrom**(-1)"
+#define XSH_SDP_FLUX_UNIT                   "erg.cm**(-2).s**(-1).angstrom**(-1)"
 #define XSH_SDP_COLUMN_WAVE                 "WAVE"
 #define XSH_SDP_COLUMN_WAVE_UNIT            "nm"
 #define XSH_SDP_COLUMN_WAVE_FORMAT          "1E"
