@@ -208,4 +208,22 @@ cpl_frame* xsh_frame_image_mult_by_fct(cpl_frame* frm,const int fctx, const int
 cpl_frame* 
 xsh_frame_image_div_by_fct(cpl_frame* frm,const int fctx, const int fcty);
 cpl_error_code xsh_image_cut_dichroic_uvb(cpl_frame* frame1d);
+
+cpl_image*
+xsh_compute_scale(cpl_imagelist* iml_data, cpl_mask* bpm,
+                  const int mode, const int win_hsz);
+cpl_image*
+xsh_compute_scale_tab(cpl_imagelist* iml_data, cpl_mask* bpm, cpl_table* tab_bpm,
+                  const int mode, const int win_hsz);
+cpl_image*
+xsh_compute_scale_tab2(cpl_imagelist* iml_data, cpl_imagelist* iml_qual,
+		               cpl_mask* bpm, cpl_table* tab_bpm, const int mode,
+					   const int win_hsz, const int decode_bp);
+
+cpl_image*
+xsh_compute_scale_tab3(cpl_imagelist* iml_data, cpl_imagelist* iml_qual,
+		               cpl_mask* bpm, cpl_table* tab_bpm, const int mode,
+					   const int win_hsz, const int decode_bp);
+cpl_table*
+xsh_qual2tab(cpl_image* bpm,const int code);
 #endif
