@@ -904,13 +904,12 @@ double
 xsh_polynomial_derivative_1d(const polynomial *p, double x)
 {
     double result = 0;
-    double dummy;
 
     assure(p != NULL, CPL_ERROR_NULL_INPUT, "Null polynomial");
     assure(xsh_polynomial_get_dimension(p) == 1, 
        CPL_ERROR_ILLEGAL_INPUT, "Polynomial must be 1d");
     
-    check_msg( dummy = cpl_polynomial_eval_1d(p->pol, (x - p->shift[1])/p->scale[1], &result),
+    check_msg( cpl_polynomial_eval_1d(p->pol, (x - p->shift[1])/p->scale[1], &result),
        "Error evaluating derivative");
     
   cleanup:
