@@ -549,7 +549,15 @@ static cpl_frame* xsh_frame_divide_flat( int do_flat, cpl_frame* src,
     check( result = xsh_divide_flat( src, mflat, tag, instr));
   }
   else{
-    check( result = cpl_frame_duplicate( src));
+	xsh_msg("divide ok1 %s",cpl_frame_get_filename(src));
+	xsh_pre* xframe = xsh_pre_load( src, instr);
+	char fname[FILENAME_MAX];
+	sprintf(fname,"tmp_%s",cpl_frame_get_filename(src));
+	result = xsh_pre_save(xframe,fname,cpl_frame_get_tag(src),1);
+	cpl_frame_set_filename(result,fname);
+	xsh_msg("fname=%s",fname);
+	xsh_pre_free(&xframe);
+    //check( result = cpl_frame_duplicate( src));
   }
 
   cleanup:
@@ -886,8 +894,10 @@ xsh_scired_slit_nod_fast(
        int conserve_flux=rectify_par->conserve_flux;
 
        sprintf(tag,"NOCRH_EFF_%s",xsh_instrument_arm_tostring(instrument)) ;
+       xsh_msg("before %s",cpl_frame_get_filename(nod_frame));
        check( eff2_frame =xsh_frame_divide_flat(0, nod_frame, master_flat,
                                                 tag, instrument));
+       xsh_msg("after %s",cpl_frame_get_filename(eff2_frame));
        rectify_par->conserve_flux=1;
        check(xsh_nod_rectify_and_shift_with_key(nod_name,"EFF",rec_prefix,
                                                 eff2_frame,order_tab_edges,
@@ -1166,7 +1176,141 @@ return cpl_error_get_code();
 
 }
 
+cpl_error_code
+xsh_get_normal_calibs(cpl_frameset* calib,xsh_instrument* instrument,
+		const char* recipe_id,int pscan,cpl_frame** spectral_format,
+		cpl_frame** master_bias,
+		cpl_frame** bpmap,cpl_frame** order_tab_edges,cpl_frame** master_flat)
+{
 
+	check( *spectral_format = xsh_find_spectral_format( calib, instrument));
+
+
+	if(pscan==0) {
+		/* In UVB and VIS mode */
+		if ( xsh_instrument_get_arm(instrument) != XSH_ARM_NIR){
+			/* RAWS frameset must have only one file */
+			check(*master_bias = xsh_find_master_bias( calib, instrument));
+		}
+	}
+
+	check(*bpmap=xsh_check_load_master_bpmap(calib,instrument,recipe_id));
+
+	check( *order_tab_edges = xsh_find_order_tab_edges( calib, instrument));
+
+	if( NULL == (*master_flat = xsh_find_master_flat( calib,instrument))) {
+		xsh_msg_error("You must provide a %s frame in input",
+				XSH_GET_TAG_FROM_MODE ( XSH_MASTER_FLAT, instrument));
+		goto cleanup;
+	}
+
+	cleanup:
+	return cpl_error_get_code();
+}
+
+cpl_error_code
+xsh_get_dispersion_calibs(cpl_frameset* calib, xsh_instrument* instrument,
+		const int do_computemap,
+		cpl_frame** model_config_frame, cpl_frame** wave_tab,
+		cpl_frame** wavemap)
+{
+      int recipe_use_model=FALSE;
+	  cpl_boolean mode_phys;
+	  mode_phys=xsh_mode_is_physmod(calib,instrument);
+
+	  /* one should have either model config frame or wave sol frame */
+	  if(mode_phys) {
+	    recipe_use_model = TRUE;
+	    if((*model_config_frame = xsh_find_frame_with_tag(calib,
+							      XSH_MOD_CFG_OPT_AFC,
+							      instrument)) == NULL) {
+
+	      xsh_error_reset();
+	      if ((*model_config_frame = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_OPT_2D,
+								 instrument)) == NULL) {
+	        xsh_error_reset();
+
+	        if ((*model_config_frame = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_TAB,
+								   instrument)) == NULL) {
+		  xsh_error_reset();
+	        } else {
+	           xsh_msg("RECIPE USE REFERENCE MODEL");
+	        }
+	      } else {
+	         xsh_msg("RECIPE USE OPTIMISED 2D MODEL");
+	      }
+	    } else {
+	       xsh_msg("RECIPE USE OPTIMISED AFC MODEL");
+	    }
+	  } else {
+	    xsh_msg("RECIPE USE WAVE SOLUTION");
+	    check( *wave_tab = xsh_find_wave_tab( calib, instrument));
+	    recipe_use_model = FALSE;
+	  }
+
+	  XSH_ASSURE_NOT_ILLEGAL( model_config_frame != NULL || wave_tab != NULL);
+
+	  if(do_computemap && recipe_use_model==FALSE) {
+	    check( *wavemap = xsh_find_wavemap( calib, instrument));
+	  }
+	cleanup:
+		return cpl_error_get_code();
+}
+
+static cpl_error_code
+xsh_get_response_calibs(cpl_frameset* calib, xsh_instrument* instrument,
+		const int use_sky_mask, cpl_frame** disp_tab_frame,
+		cpl_frame** response_ord_frame, cpl_frame** frm_atmext,
+		cpl_frame** skymask_frame) {
+
+	/* to compute efficiency */
+	if(NULL == (*disp_tab_frame = xsh_find_disp_tab( calib, instrument))) {
+		xsh_msg("To compute efficiency, you must provide a DISP_TAB_ARM input");
+	}
+
+	if ( use_sky_mask == TRUE){
+		xsh_msg("Using sky mask");
+		check( *skymask_frame = xsh_find_frame_with_tag( calib, XSH_SKY_LINE_LIST,
+				instrument));
+	}
+
+	check( *response_ord_frame = xsh_find_frame_with_tag(calib,
+			XSH_RESPONSE_MERGE1D_SLIT, instrument));
+
+	if(*response_ord_frame != NULL) {
+		*frm_atmext=xsh_find_frame_with_tag(calib,XSH_ATMOS_EXT,instrument);
+		if(*frm_atmext==NULL) {
+			xsh_msg_error("Provide atmospheric extinction frame");
+		}
+	}
+
+	cleanup:
+	return cpl_error_get_code();
+}
+
+cpl_error_code
+xsh_get_calibs_to_flux_calibrate(cpl_frameset* calib,
+		xsh_instrument* instrument, cpl_frame** response_ord_frame,
+		cpl_frame** frm_atmext)
+{
+
+
+	if((*response_ord_frame=xsh_find_frame_with_tag(calib,XSH_RESPONSE_MERGE1D_SLIT,
+			instrument)) == NULL ) {
+		check( *response_ord_frame = xsh_find_frame_with_tag(calib,
+				XSH_MRESPONSE_MERGE1D_SLIT,
+				instrument));
+	}
+	if(*response_ord_frame != NULL) {
+		*frm_atmext=xsh_find_frame_with_tag(calib,XSH_ATMOS_EXT,instrument);
+		if(*frm_atmext==NULL) {
+			xsh_msg_error("Provide atmospheric extinction frame");
+		}
+	}
+	cleanup:
+	return cpl_error_get_code();
+}
+//PIPPO
 cpl_error_code
 xsh_scired_slit_nod_get_calibs(cpl_frameset* raws,
                                cpl_frameset* calib,
@@ -1191,21 +1335,14 @@ xsh_scired_slit_nod_get_calibs(cpl_frameset* raws,
                    const char* recipe_id)
 
 {
+
+  xsh_get_normal_calibs(calib, instrument, recipe_id, pscan, spectral_format,
+			master_bias, bpmap, order_tab_edges, master_flat);
   int recipe_use_model=FALSE;
   cpl_frame* ref_frame=NULL;
   cpl_boolean mode_phys;
   mode_phys=xsh_mode_is_physmod(calib,instrument);
-  check(*bpmap=xsh_check_load_master_bpmap(calib,instrument,recipe_id));
 
-  if(pscan==0) {
-     /* In UVB and VIS mode */
-     if ( xsh_instrument_get_arm(instrument) != XSH_ARM_NIR){
-        /* RAWS frameset must have only one file */
-        check(*master_bias = xsh_find_master_bias( calib, instrument));
-     }
-  }
-
-  check( *order_tab_edges = xsh_find_order_tab_edges( calib, instrument));
 
   /* one should have either model config frame or wave sol frame */
   if(mode_phys) {
@@ -1239,11 +1376,7 @@ xsh_scired_slit_nod_get_calibs(cpl_frameset* raws,
 
   XSH_ASSURE_NOT_ILLEGAL( model_config_frame != NULL || wave_tab != NULL);
 
-  if( NULL == (*master_flat = xsh_find_master_flat( calib,instrument))) {
-    xsh_msg_error("You must provide a %s frame in input",
-          XSH_GET_TAG_FROM_MODE ( XSH_MASTER_FLAT, instrument));
-    goto cleanup;
-  }
+
   if(do_computemap && recipe_use_model==FALSE) {
     check( *wavemap = xsh_find_wavemap( calib, instrument));
   }
@@ -1263,25 +1396,15 @@ xsh_scired_slit_nod_get_calibs(cpl_frameset* raws,
                 do_computemap, recipe_use_model, rec_prefix,
                 wavemap, slitmap));
 
-  check( *spectral_format = xsh_find_spectral_format( calib, instrument));
 
   if ( use_skymask == TRUE){
     xsh_msg("Using sky mask");
     check( *skymask_frame = xsh_find_frame_with_tag( calib, XSH_SKY_LINE_LIST,
                              instrument));
   }
-  if((*response_ord_frame=xsh_find_frame_with_tag(calib,XSH_RESPONSE_MERGE1D_SLIT,
-                                                  instrument)) == NULL ) {
-    check( *response_ord_frame = xsh_find_frame_with_tag(calib,
-                             XSH_MRESPONSE_MERGE1D_SLIT,
-                             instrument));
-  }
-  if(*response_ord_frame != NULL) {
-    *frm_atmext=xsh_find_frame_with_tag(calib,XSH_ATMOS_EXT,instrument);
-    if(*frm_atmext==NULL) {
-      xsh_msg_error("Provide atmospheric extinction frame");
-    }
-  }
+
+  xsh_get_calibs_to_flux_calibrate(calib, instrument, response_ord_frame,
+		  frm_atmext);
 
  cleanup:
   return cpl_error_get_code();
@@ -1312,86 +1435,18 @@ xsh_respon_slit_nod_get_calibs(cpl_frameset* calib,
 			       const char* recipe_id)
 
 {
-  int recipe_use_model=FALSE;
-  cpl_boolean mode_phys;
-  mode_phys=xsh_mode_is_physmod(calib,instrument);
-  check(*bpmap=xsh_check_load_master_bpmap(calib,instrument,recipe_id));
 
-  if(pscan==0) {
-     /* In UVB and VIS mode */
-     if ( xsh_instrument_get_arm(instrument) != XSH_ARM_NIR){
-        /* RAWS frameset must have only one file */
-        check(*master_bias = xsh_find_master_bias( calib, instrument));
-     }
-  }
+	xsh_get_normal_calibs(calib, instrument, recipe_id, pscan, spectral_format,
+			master_bias, bpmap, order_tab_edges, master_flat);
 
-  check( *order_tab_edges = xsh_find_order_tab_edges( calib, instrument));
+	xsh_get_dispersion_calibs(calib, instrument, do_computemap,
+			model_config_frame, wave_tab, wavemap);
 
-  /* one should have either model config frame or wave sol frame */
-  if(mode_phys) {
-    recipe_use_model = TRUE;
-    if((*model_config_frame = xsh_find_frame_with_tag(calib,
-						      XSH_MOD_CFG_OPT_AFC,
-						      instrument)) == NULL) {
+	xsh_get_response_calibs(calib, instrument, use_skymask, disp_tab_frame,
+			response_ord_frame, frm_atmext, skymask_frame);
 
-      xsh_error_reset();
-      if ((*model_config_frame = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_OPT_2D, 
-							 instrument)) == NULL) {
-        xsh_error_reset();
-
-        if ((*model_config_frame = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_TAB, 
-							   instrument)) == NULL) {
-	  xsh_error_reset();
-        } else {
-           xsh_msg("RECIPE USE REFERENCE MODEL");
-        }
-      } else {
-         xsh_msg("RECIPE USE OPTIMISED 2D MODEL");
-      }
-    } else {
-       xsh_msg("RECIPE USE OPTIMISED AFC MODEL");
-    }
-  } else {
-    xsh_msg("RECIPE USE WAVE SOLUTION");
-    check( *wave_tab = xsh_find_wave_tab( calib, instrument));
-    recipe_use_model = FALSE;
-  }
-
-  XSH_ASSURE_NOT_ILLEGAL( model_config_frame != NULL || wave_tab != NULL);
-
-  if( NULL == (*master_flat = xsh_find_master_flat( calib,instrument))) {
-    xsh_msg_error("You must provide a %s frame in input",
-		  XSH_GET_TAG_FROM_MODE ( XSH_MASTER_FLAT, instrument));
-    goto cleanup;
-  }
-  if(do_computemap && recipe_use_model==FALSE) {
-    check( *wavemap = xsh_find_wavemap( calib, instrument));
-  } 
-  /* to compute efficiency */
-  if(NULL == (*disp_tab_frame = xsh_find_disp_tab( calib, instrument))) {
-    xsh_msg("To compute efficiency, you must provide a DISP_TAB_ARM input");
-  }
-
-  check( *spectral_format = xsh_find_spectral_format( calib, instrument));
-
-  if ( use_skymask == TRUE){
-    xsh_msg("Using sky mask");
-    check( *skymask_frame = xsh_find_frame_with_tag( calib, XSH_SKY_LINE_LIST,
-						     instrument));
-  }
-
-  check( *response_ord_frame = xsh_find_frame_with_tag(calib,
-							 XSH_RESPONSE_MERGE1D_SLIT, instrument));
-
-  if(*response_ord_frame != NULL) { 
-    *frm_atmext=xsh_find_frame_with_tag(calib,XSH_ATMOS_EXT,instrument);
-    if(*frm_atmext==NULL) {
-      xsh_msg_error("Provide atmospheric extinction frame");
-    }
-  }
-
- cleanup:
-  return cpl_error_get_code();
+	cleanup:
+	return cpl_error_get_code();
 }
 
 /* for the moment not used */
@@ -1601,8 +1656,8 @@ xsh_ifu_stare_get_calibs(cpl_frameset* calib,
                           int pscan)
 {
 
-    cpl_boolean mode_phys;
-    mode_phys=xsh_mode_is_physmod(calib,inst);
+    //cpl_boolean mode_phys;
+    //mode_phys=xsh_mode_is_physmod(calib,inst);
     check(*spectral_format = xsh_find_spectral_format( calib, inst));
 
     XSH_ASSURE_NOT_NULL_MSG(*spectral_format,"Null input spectral format frame");
@@ -1638,11 +1693,11 @@ xsh_ifu_stare_get_calibs(cpl_frameset* calib,
     /* One of model config and wave tab must be present, but only one ! */
     if ( *model_cfg == NULL){
         xsh_msg("RECIPE USE WAVE SOLUTION");
-        recipe_use_model = FALSE;
+        *recipe_use_model = FALSE;
     }
     else{
         xsh_msg("RECIPE USE MODEL");
-        recipe_use_model = TRUE;
+        *recipe_use_model = TRUE;
     }
 
     if( ( *model_cfg !=NULL) && (*wavesol != NULL) ) {
@@ -1685,6 +1740,38 @@ xsh_ifu_stare_get_calibs(cpl_frameset* calib,
 
 }
 
+cpl_error_code
+xsh_get_slit_stare_calibs(cpl_frameset* calib, xsh_instrument* instrument,
+		cpl_frame** sky_list, cpl_frame** model_cfg,  cpl_frame** qc_sky,
+		cpl_frame** sframe_sky_sub_tab, cpl_frame** sky_orders_chunks)
+{
+	check(*sky_list = xsh_find_frame_with_tag( calib, XSH_SKY_LINE_LIST,
+			instrument));
+	if ( *model_cfg != NULL){
+
+		if ( *sky_list != NULL){
+			/* we compute unbinned THE map to easier plots from QC garching */
+			check(*qc_sky=xsh_util_physmod_model_THE_create(*model_cfg,instrument,
+					*sky_list,1,1,9,1));
+		}
+	}
+
+	/* optional frames */
+	if ((*sframe_sky_sub_tab = xsh_find_frame_with_tag(calib,XSH_SKY_SUB_BKPTS,
+			instrument)) == NULL) {
+		xsh_error_reset();
+	} else {
+		xsh_msg_warning("Data reduction with user defined break points number from file %s",
+				cpl_frame_get_filename(*sframe_sky_sub_tab));
+	}
+	*sky_orders_chunks = xsh_find_frame_with_tag(calib,XSH_SKY_ORDERS_CHUNKS, instrument);
+
+	cleanup:
+
+	return cpl_error_get_code();
+}
+
+
 cpl_error_code
 xsh_slit_stare_get_calibs(cpl_frameset* calib,
                           xsh_instrument* instrument,
@@ -1744,11 +1831,11 @@ xsh_slit_stare_get_calibs(cpl_frameset* calib,
      if((*model_cfg = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_OPT_AFC,
 					      instrument)) == NULL) {
        xsh_error_reset();
-       if ((*model_cfg = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_OPT_2D, 
+       if ((*model_cfg = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_OPT_2D,
 						 instrument)) == NULL) {
          xsh_error_reset();
 
-         if ((*model_cfg = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_TAB, 
+         if ((*model_cfg = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_TAB,
                                                    instrument)) == NULL) {
 	   xsh_error_reset();
          } else {
@@ -1797,67 +1884,84 @@ xsh_slit_stare_get_calibs(cpl_frameset* calib,
 }
 
 cpl_error_code
-xsh_slit_offset_get_calibs(cpl_frameset* calib,xsh_instrument* instrument,
-                           cpl_frame** bpmap,cpl_frame** mbias,
-                           cpl_frame** mdark, cpl_frame** otab_edges,
-                           cpl_frame** model_cfg, cpl_frame** wave_tab,
-                           cpl_frame** mflat, cpl_frame** wmap, cpl_frame** smap,
-                           cpl_frame** spectral_format,const char* rec_id)
+xsh_slit_stare_get_calibs2(cpl_frameset* calib,
+		xsh_instrument* instrument,
+		cpl_frame** spectralformat,
+		cpl_frame** mbias,
+		cpl_frame** mdark,
+		cpl_frame** mflat,
+		cpl_frame** otab_edges,
+		cpl_frame** model_cfg,
+		cpl_frame** wave_tab,
+		cpl_frame** sky_list,
+		cpl_frame** sky_orders_chunks,
+		cpl_frame** qc_sky,
+		cpl_frame** bpmap,
+		cpl_frame** sframe_sky_sub_tab,
+		cpl_frame** wmap,
+		cpl_frame** smap,
+		const char* rec_id,
+		int * recipe_use_model,
+		int pscan)
 {
 
 
-   cpl_boolean mode_phys;
-   mode_phys=xsh_mode_is_physmod(calib,instrument);
+	xsh_get_normal_calibs(calib, instrument, rec_id, pscan, spectralformat, mbias,
+			bpmap, otab_edges, mflat);
+	//The following should go in xsh_get_normal_calibs()
+	check(xsh_instrument_update_from_spectralformat(instrument,*spectralformat));
 
-   check(*bpmap=xsh_check_load_master_bpmap(calib,instrument,rec_id));
 
-   /* In UVB and VIS mode */
-   if ( xsh_instrument_get_arm(instrument) != XSH_ARM_NIR){
-      /* RAWS frameset must have only one file */
-      check( *mbias = xsh_find_frame_with_tag(calib,XSH_MASTER_BIAS,instrument));
-   }
+	if((*mdark =  xsh_find_master_dark( calib, instrument))==NULL) {
+		xsh_msg_warning("Frame %s not provided",XSH_MASTER_DARK);
+		xsh_error_reset();
+	}
 
-   /* TODO: Is mdark input really needed? */
-   if((*mdark=xsh_find_frame_with_tag(calib,XSH_MASTER_DARK,instrument))==NULL){
-      xsh_error_reset();
-   }
+	//TODO: extra param, should come from recipe caller.
+	int do_computemap=1;
+	xsh_get_dispersion_calibs( calib, instrument, do_computemap, model_cfg,
+			wave_tab, wmap);
+	//TODO: the following two lines should be moved to xsh_get_dispersion_calibs()
+	check(*wmap = xsh_find_frame_with_tag(calib,XSH_WAVE_MAP,instrument));
+	check(*smap = xsh_find_frame_with_tag(calib,XSH_SLIT_MAP,instrument));
 
-   check( *otab_edges = xsh_find_order_tab_edges( calib, instrument));
-   if(mode_phys) {
-     if((*model_cfg=xsh_find_frame_with_tag(calib,XSH_MOD_CFG_OPT_AFC,instrument)) == NULL) {
-       xsh_error_reset();
-       if ((*model_cfg = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_OPT_2D, 
-						 instrument)) == NULL) {
-         xsh_error_reset();
+	xsh_get_slit_stare_calibs(calib, instrument, sky_list, model_cfg, qc_sky,
+			sframe_sky_sub_tab, sky_orders_chunks);
 
-         if ((*model_cfg = xsh_find_frame_with_tag(calib,XSH_MOD_CFG_TAB, 
-                                                   instrument)) == NULL) {
-	   xsh_error_reset();
-         } else {
-            xsh_msg("RECIPE USE REFERENCE MODEL");
-         }
-       } else {
-          xsh_msg("RECIPE USE OPTIMIZED 2D MODEL");
-       }
-     } else {
-        xsh_msg("RECIPE USE OPTIMIZED AFC MODEL");
-     }
-   } else {
+	cleanup:
 
-     *wave_tab = xsh_find_wave_tab( calib, instrument ) ;
-   }
+	return cpl_error_get_code();
+}
 
-   XSH_ASSURE_NOT_ILLEGAL( *model_cfg != NULL || *wave_tab != NULL ) ;
+cpl_error_code
+xsh_slit_offset_get_calibs(cpl_frameset* calib,xsh_instrument* instrument,
+		cpl_frame** bpmap,cpl_frame** mbias,
+		cpl_frame** mdark, cpl_frame** otab_edges,
+		cpl_frame** model_cfg, cpl_frame** wave_tab,
+		cpl_frame** mflat, cpl_frame** wmap, cpl_frame** smap,
+		cpl_frame** spectral_format,const char* rec_id)
+{
 
-   check( *mflat = xsh_find_master_flat( calib, instrument));
+	int pscan=0; //extra.
+	xsh_get_normal_calibs(calib, instrument, rec_id, pscan, spectral_format,
+			mbias, bpmap, otab_edges, mflat);
 
-   check( *wmap = xsh_find_wavemap( calib, instrument));
-   check( *smap = xsh_find_slitmap( calib, instrument));
-   check( *spectral_format = xsh_find_spectral_format( calib, instrument));
+	/* TODO: Is mdark input really needed? */
+	if((*mdark=xsh_find_frame_with_tag(calib,XSH_MASTER_DARK,instrument))==NULL){
+		xsh_error_reset();
+	}
 
- 
-  cleanup:
-   return cpl_error_get_code();
+	//The following need to be defined
+	int do_computemap=1;
+	xsh_get_dispersion_calibs(calib, instrument, do_computemap, model_cfg,
+			wave_tab, wmap);
+	//The following is also present in xsh_get_dispersion_calibs
+	check( *wmap = xsh_find_wavemap( calib, instrument));
+	//The following should be removed to xsh_get_dispersion_calibs
+	check( *smap = xsh_find_slitmap( calib, instrument));
+
+	cleanup:
+	return cpl_error_get_code();
 
 }
 
@@ -2039,7 +2143,7 @@ xsh_slit_stare_correct_crh_and_sky(xsh_localize_obj_param * loc_obj_par,
             check(xsh_frame_image_save(rmbkg,"rmbkg.fits"));
             xsh_msg("instrument=%p",instrument);
             check( sub_sky = xsh_check_subtract_sky_single( CPL_TRUE, rmbkg,
-                            order_tab_edges, slitmap, wavemap, sky_map,
+                            order_tab_edges, slitmap, wavemap, NULL,
                             single_frame_sky_sub_tab, instrument, sub_sky_nbkpts1,
                             sky_par,ref_sky_list, sky_orders_chunks,sky, sky_eso, sky_ima, sky_tag,clean_tmp));
             xsh_add_temporary_file(sky_name);
@@ -2561,6 +2665,7 @@ xsh_compute_wavelength_resampling_accuracy(cpl_frame* wavemap,
   int nline=1;
   cpl_propertylist* xhead=NULL;
   cpl_vector* xvec=NULL;
+  cpl_table* xtab=NULL;
   cpl_propertylist* phead=NULL;
   double csyer1=0;
 
@@ -2608,53 +2713,83 @@ xsh_compute_wavelength_resampling_accuracy(cpl_frame* wavemap,
 
     frm_tmp=xsh_spectrum_save(s,name,tag);
 
-  } else if( (strstr(tag,"ORDER1D")!=NULL) ||
-             (strstr(tag,"SKY_ORD1D")!=NULL) ) {
-     xsh_msg("ORDER1D");
+  } else if( strstr(tag,"ORDER1D")!=NULL ) {
+	  xsh_msg("ORDER1D");
+	  int nbext=0;
+	  int i=0;
+	  char cmd[256];
+	  const char *tname = "tmp_ima.fits";
+	  nbext = cpl_frame_get_nextensions( science);
+	  check(phead = cpl_propertylist_load( name, 0 ));
+	  //ima=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
+	  vec=cpl_vector_load(name,0);
 
+	  sprintf(cmd,"mv  %s %s",name,tname);
+	  system(cmd);
+	  xsh_add_temporary_file("tmp_ima.fits");
+	  cpl_propertylist_insert_after_int(phead,"DATE",XSH_LAMNLIN,nline);
+	  cpl_propertylist_set_comment(phead,XSH_LAMNLIN,XSH_LAMNLIN_C);
+	  check(xsh_plist_set_wave_accuracy(phead,wrms,werr,csyer1));
 
-     int nbext=0;
-     int i=0;
-     char cmd[256];
-     const char *tname = "tmp_ima.fits";
-
-
-     nbext = cpl_frame_get_nextensions( science);
-     check(phead = cpl_propertylist_load( name, 0 ));
-     //ima=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
-     vec=cpl_vector_load(name,0);
-
-     sprintf(cmd,"mv  %s %s",name,tname);
-     system(cmd);
-     xsh_add_temporary_file("tmp_ima.fits");
-     cpl_propertylist_insert_after_int(phead,"DATE",XSH_LAMNLIN,nline);
-     cpl_propertylist_set_comment(phead,XSH_LAMNLIN,XSH_LAMNLIN_C);
-     check(xsh_plist_set_wave_accuracy(phead,wrms,werr,csyer1));
-
-
-       check(cpl_vector_save(vec, name, CPL_BPP_IEEE_FLOAT,
-              phead,CPL_IO_DEFAULT));
-       for( i = 0 ; i<=nbext ; i++ ) {
-         int extension ;
-         xsh_free_vector( &xvec) ;
-         xsh_free_propertylist( &xhead) ;
-         check(xvec = cpl_vector_load( tname,i ));
-         check(xhead = cpl_propertylist_load( tname ,i));
-         if ( i == 0 ) {
-           extension = CPL_IO_DEFAULT ;
-           check(cpl_vector_save(xvec, name, CPL_BPP_IEEE_FLOAT,
-                  phead,extension));
-         }
-         else {
-           extension = CPL_IO_EXTEND ;
-       check(cpl_vector_save(xvec, name, CPL_BPP_IEEE_FLOAT,xhead,extension));
-         }
-       }
-       sprintf(cmd,"rm  tmp_ima.fits");
-       system(cmd);
+	  check(cpl_vector_save(vec, name, CPL_BPP_IEEE_FLOAT,
+			  phead,CPL_IO_DEFAULT));
+	  for( i = 0 ; i<=nbext ; i++ ) {
+		  int extension ;
+		  xsh_free_vector( &xvec) ;
+		  xsh_free_propertylist( &xhead) ;
+		  check(xvec = cpl_vector_load( tname,i ));
+		  check(xhead = cpl_propertylist_load( tname ,i));
+		  if ( i == 0 ) {
+			  extension = CPL_IO_DEFAULT ;
+			  check(cpl_vector_save(xvec, name, CPL_BPP_IEEE_FLOAT,
+					  phead,extension));
+		  }
+		  else {
+			  extension = CPL_IO_EXTEND ;
+			  check(cpl_vector_save(xvec, name, CPL_BPP_IEEE_FLOAT,xhead,extension));
+		  }
+	  }
+	  sprintf(cmd,"rm  tmp_ima.fits");
+	  system(cmd);
 
   } else if(strstr(tag,"SKY_ORD1D")!=NULL) {
-     xsh_msg("SKY_ORD1D");
+	  xsh_msg("SKY_ORD1D");
+
+	  int nbext=0;
+	  int i=0;
+	  char cmd[256];
+	  const char *tname = "tmp_tab.fits";
+	  nbext = cpl_frame_get_nextensions( science);
+	  check(phead = cpl_propertylist_load( name, 0 ));
+      xsh_msg("name=%s",name);
+	  check(tab=cpl_table_load(name,1,0));
+
+	  sprintf(cmd,"mv  %s %s",name,tname);
+	  system(cmd);
+	  xsh_add_temporary_file(tname);
+	  cpl_propertylist_insert_after_int(phead,"DATE",XSH_LAMNLIN,nline);
+	  cpl_propertylist_set_comment(phead,XSH_LAMNLIN,XSH_LAMNLIN_C);
+	  check(xsh_plist_set_wave_accuracy(phead,wrms,werr,csyer1));
+
+	  check(cpl_table_save(tab, phead, NULL, name, CPL_IO_DEFAULT));
+	  for( i = 0 ; i<=nbext ; i++ ) {
+		  int extension ;
+		  xsh_free_table( &xtab) ;
+		  xsh_free_propertylist( &xhead) ;
+		  check(xtab = cpl_table_load( tname,1, i ));
+		  check(xhead = cpl_propertylist_load( tname ,i));
+		  if ( i == 0 ) {
+			  extension = CPL_IO_DEFAULT ;
+			  check(cpl_table_save(xtab, phead, NULL, name, extension));
+		  }
+		  else {
+			  extension = CPL_IO_EXTEND ;
+			  check(cpl_table_save(xtab, phead, NULL, name, extension));
+
+		  }
+	  }
+	  sprintf(cmd,"rm  tmp_tab.fits");
+	  system(cmd);
 
   }
   xsh_msg("processed frame %s",tag);
@@ -2670,6 +2805,7 @@ xsh_compute_wavelength_resampling_accuracy(cpl_frame* wavemap,
   xsh_free_image(&wmap_ima);
   xsh_free_propertylist(&plist);
   xsh_spectrum_free(&s);
+  xsh_print_rec_status(0);
   return cpl_error_get_code();
 
 }
@@ -2716,9 +2852,9 @@ xsh_frameset_crh_single(cpl_frameset* raws,
  sprintf( arm_str, "%s",  xsh_instrument_arm_tostring(instrument) ) ;
  nraws=cpl_frameset_get_size(raws);
  check( clean = cpl_frameset_new() ) ;
- xsh_msg( "Remove crh (single frame)" ) ;
+ /* AMO: Don't do CRH single on a raw frame, need to be done on a sky corrected one */
  if ( crh_single_par->nb_iter > 0 ) {
-    xsh_msg( "removecrhsingle_niter > 0" ) ;
+    xsh_msg( "Detect crh (single frame) as removecrhsingle_niter > 0" ) ;
     for ( i = 0 ; i < nraws ; i++ ) {
 
       frm = cpl_frameset_get_frame( raws, i )  ;
@@ -2730,6 +2866,7 @@ xsh_frameset_crh_single(cpl_frameset* raws,
       cpl_frameset_insert( clean, rm_crh ) ;
     }
   } else {
+    xsh_msg_warning( "Skip Remove crh (single frame) on not sky corrected frame" ) ;
     clean=cpl_frameset_duplicate(raws);
   }
  if( sky_map_frm != NULL ) {
